set more off
set type double

cd "/home/argyle/bargyle13/auto_credit"



*BRING IN DATA SET**************************************************************'
import delimited /home/auto_credit/Locations/auto_data_5158401_20160603.csv, clear 
save ./tmp/half1.dta, replace
import delimited /home/auto_credit/Locations/auto_data_5471975_20160603.csv, clear 
*import delimited /data/argyle/veAutoLoanData_0517_1.csv, clear 
*save ./tmp/half1.dta, replace
*import delimited /data/argyle/veAutoLoanData_0517_2.csv, clear 
append using ./tmp/half1.dta, force //combine  the two halves
save ./tmp/auto_credit_dirty.dta, replace

*------------------------------------------------------------------------------*


******USE VIN DICTIONARY TO CLEAN UP CODING*************************************
import delimited /data/argyle/veMakeModelDictionary_ALL_20160511.csv, clear 
*automake/automodel is the entry in the original data set, vemake & vemodel are the cleaned up versions
duplicates drop automodel vemake vemodel, force 
drop if automodel == "#NAME?"
save ./tmp/make_model_dict.dta, replace

import delimited /data/argyle/veMakeDictionary.csv, clear 
*automodel is the entry in the original data set, vemake & vemodel are the cleaned up versions
duplicates drop automake vemake, force 
drop if automake == "#NAME?"
save ./tmp/make_dict.dta, replace

import delimited /data/argyle/BSA_vin_dict.csv, clear 
gen mm = substr(vin,1,8) // pull the first 8 digits of the vin (this is the make/model data
gen pl = substr(vin,10,2) // pull the plant and plant location (also separated)
duplicates drop mm pl, force // only keep unique mm pl pairs (the fact that we're dropping here implies the vin decoding could have been much faster (maybe)
drop if missing(mm) | missing(pl) // drop if we are missing mm or pl
save ./tmp/ba_vin_dict.dta, replace
*------------------------------------------------------------------------------*

*****msa dictionary*********************************************************
import excel "/data/argyle/zip_to_msa.xls", sheet("fs10gpci by ZIP, owcp") cellrange(A8:H43495) firstrow clear //from http://www.dol.gov/owcp/regs/feeschedule/fee/fee10/fs10_gpci_by_ZIP.xls
rename GPCI wGPCI
rename E peGPCI
rename F meGPCI
rename ZIPCODE zipcode
rename STATE msastate
rename MSANo msa
destring(msa), force replace
destring(zipcode), force replace
save ./tmp/zip_to_msa.dta, replace
*------------------------------------------------------------------------------*

*****trim dictionary*********************************************************
import delimited "/home/argyle/bargyle13/auto_credit/tmp/BSA_vin_dict_w_trim.csv",  clear //taken from the DOT website
rename baseries cseries
rename batrim ctrim
replace vin = upper(vin)
gen mm = substr(vin,1,8) // pull the first 8 digits of the vin (this is the make/model data
gen pl = substr(vin,10,2) // pull the plant and plant location (also separated)
duplicates drop mm pl, force // only keep unique mm pl pairs (the fact that we're dropping here implies the vin decoding could have been much faster (maybe)
drop if missing(mm) | missing(pl) // drop if we are missing mm or pl
save ./tmp/bsa_trim_dict.dta, replace
*------------------------------------------------------------------------------*


*# OF LENDERS*******************************************************************
use "/home/argyle/Downloads/total lenders in msa.dta", clear
rename cbsa10 msa
save ./tmp/lender_msa.dta, replace
*------------------------------------------------------------------------------*

*IDs to lenders*******************************************************************
import delimited "/data/argyle/portfolio ids and locations.csv", clear 
rename id loanportfolioid
save ./tmp/id_to_name.dta, replace
*------------------------------------------------------------------------------*


*# OF LENDERS*******************************************************************
import delimited /data/argyle/LP_to_CU.csv, delimiter(comma) clear 
destring(cu_number), force replace ignore(",")
mmerge cu_number using /data/argyle/cu_tom.dta
rename id loanportfolioid
drop if missing(loanportfolioid)
save ./tmp/cu_tom.dta, replace
*------------------------------------------------------------------------------*

*# OF LENDERS*******************************************************************
import delimited /home/argyle/bargyle13/credit_desert/tmp/borr_dist.csv, delimiter(comma) clear 
drop v1
save ./tmp/borr_dist.dta, replace

import  delimited using ../credit_desert/tmp/borr_data_to_merge.csv, delimiter(comma) clear //this is the pre-distance calculation file...which was the old auto_clean.dta
keep marker address city borrstate borrzip
mmerge marker using ./tmp/borr_dist.dta, type(1:1) 
sort address city borrstate borrzip, stable
drop marker
gen marker = _n
save ./tmp/borr_dist.dta, replace
*------------------------------------------------------------------------------*

***IMPORT MSA DATA**************************************************************
import excel "/data/argyle/msa_data.xls", sheet("Chapter 3") cellrange(A4:K986) firstrow clear
rename CBSA msa
drop if missing(msa)
gen temp = strlen(msa)
drop if temp > 5
drop temp
rename Population population_2000
rename E population_2010
rename Land landarea
rename Populationd popdensity_2000
rename H popdensity_2010
drop I J K
destring msa, force replace
save ./tmp/msa_data.dta, replace
*------------------------------------------------------------------------------*


*****MERGE WITH DICTS and CREATE CORRECTED VERSIONS*****************************
use ./tmp/auto_credit_dirty.dta, clear //load dirty dataset
destring(zipcode), force replace
mmerge zipcode using ./tmp/zip_to_msa.dta, type(n:1) unmatched(master) uk(msa msastate) //merge zip to get MSA and corrected STate
mmerge msa using ./tmp/lender_msa.dta, type(n:1) unmatched(master) 
mmerge loanportfolioid using ./tmp/id_to_name.dta, type(n:1) unmatched(master) 
mmerge msa using ./tmp/msa_data.dta, type(n:1) unmatched(master) 
mmerge msa using /data/argyle/competitionmeasures0511.dta, type(n:1) unmatched(master)  //using .dta file emailed from Chris Palmer.  Had to drop MSA==0
mmerge automake using ./tmp/make_dict.dta, type(n:1) unm(master) //first merge using the make_dict, keep everything in the master
drop if missing(loanportfolioid) //only drops 4 observations
mmerge loanportfolioid using ./tmp/cu_tom.dta, type(n:1) unmatched(master) uk(tom_code) //merge with tom_codes...dropping address and charter info
rename vemake vemake2 //keep the vemake merged as vemake2
mmerge automodel using ./tmp/make_model_dict.dta, type(n:1) unm(master) //merge using the make_model_dict
replace vemake = vemake2 if vemake == "" //fill in the vemake variables that is available from make_dict if it is not filled in with make_model_dict.
gen mm = substr(autovin,1,8) // pull the first 8 digits of the vin (this is the make/model data
gen pl = substr(autovin,10,2) // pull the plant and plant location (also separated)
mmerge mm pl using ./tmp/ba_vin_dict.dta, type(n:1) unm(master) //merge using the vin dict
mmerge mm pl using ./tmp/bsa_trim_dict.dta, type(n:1) unm(master) //merge using the vin dict


gen cmake = vemake //corrected version (by VE and BA)
gen cmodel = vemodel //corrected version (by VE and BA)
replace cmake = bamake if cmake=="" //fill in cmake from vin if cmake is missing
replace cmodel = bamodel if cmodel=="" //fill in cmodel from vin if cmodel is missing
replace cmake = lower(cmake)
replace cmodel = lower(cmodel)
gen cautoyear = autoyear
replace cautoyear = baautoyear if missing(cautoyear) //corrected version (by VE and BA)
gen cstate = msastate //the state data from the msa dictionary is much cleaner, but there are zips that are unfound that have recognizeable state abbreviations
replace cstate = state if missing(cstate) // so fill in corrected state with the origianl data, if the msa state didn't comethrough
//cmake and cmodel are thus the best, most complete descriptions of make and model
*------------------------------------------------------------------------------*

*GENERATE NEW VARIABLES AND FILTER**********************************************
rename v40 borrstate
rename v41 borrzip
drop vemake* vemodel* bamake bamodel autoyear automake automodel mm pl msastate state v1 //clean up unneeded variables

gen monpay = (annualintrate/12)/(1-(1+annualintrate/12)^(-loanterm))*origloanam //generate monthly payment
replace isindirect ="1" if isindirect == "true" //convert isindirect to dummy. Code "true" as astring "1"
replace isindirect ="0" if isindirect == "false" //code "false' as "0"
destring(isindirect), force replace ///destring isinidrect

replace ischargeoff ="1" if ischargeoff == "true" //convert ischargeoff to dummy. Code "true" as astring "1"
replace ischargeoff ="0" if ischargeoff == "false" //code "false' as "0"
destring(ischargeoff), force replace ///destring ischargeoff

gen loandate = date(loanclose,"YMD")
gen loanyear = year(loandate)
gen loanmon = month(loandate)
gen loanday = day(loandate)
gen loanquarter = 1 if loanmon >=1 & loanmon <=3
replace loanquarter = 2 if loanmon >=4 & loanmon <=6
replace loanquarter = 3 if loanmon >= 7 & loanmon <=9
replace loanquarter = 4 if loanmon >=10  & loanmon <=12
gen carage = loanyear - cautoyear //generate car age
gen ld = sum_lenders/landarea //Lender Density = # of lenders/square mileage of MSA
gen downpayment = origvalue - origloanam

bys loanportfolio: egen tot_days = total(daysdel)
bys loanportfolio: gen has_days =1 if ~missing(tot_days) 
gen default = 0 if has_days == 1
replace default = 1 if daysdel >=90 & has_days ==1 & ~missing(daysdel)

drop if cautoyear < 1950 // drop cars betfore 1970
drop if loanterm == . | loanterm <= 0 | loanterm > 240 //drop if loanterm is missing, nonpositive, or longer than 240 months
drop if missing(origvalue) | origvalue <= 500 | origvalue > 100000 //drop if collateral value is missing, nonpositive, greater than $100k
drop if debtratio < 0 | debtratio > 10 & ~missing(debtratio) //drop if DTI is less than zero or greater than 10
drop if origloanam < 500 | origloanam > 100000 //drop if loan amount is less than $500 or greater than $100k (i.e. or missing)

keep if monpay >= 50 & monpay <=1500 //drop observations with a monthly payment less than $50 and more than $1500
keep if loanyear >=2005
bys loanport: gen nol = _N //generate Number of Loans for each CU
drop if nol <= 1000 // drop all observations from Credit Unions with less than 1000 observations
drop nol
drop if loanport == 352 | annualintrate >= .1649 //drop the financial firm and too high of interest rates (top 1%)
*------------------------------------------------------------------------------*
bys address city borrstate borrzip loanyear loanmon (mostrecent): gen dup = cond(_N==1,0,_n)
bys address city borrstate borrzip loanyear loanmon  (mostrecent): egen maxdup = max(dup) //keep the most recent if there are duplicates
keep if dup == maxdup
drop dup maxdup
drop if missing(address) | missing(borrstate) | missing(borrzip)
sort address city borrstate borrzip origvalue, stable
gen marker = _n
export delimited marker address cityname borrstate borrzip loanyear loanmon using "/home/argyle/bargyle13/credit_desert/tmp/borr_data_uncoded", delimiter(tab) replace
***to distance calculator

mmerge marker using ../credit_desert/tmp/borr_dist_big.dta, type(1:1)
*/
gen lender_cat = "CU" if strpos(strlower(namefull),"credit") |  ~missing(tom)
replace lender_cat = "Fin" if  strpos(strlower(namefull),"fina") & missing(lender_cat)
replace lender_cat = "Bank"  if strpos(strlower(namefull),"bank") & missing(lender_cat)
replace lender_cat = "Fin" if missing(lender_cat) 
gen delta = (ficoborrcurr - origfico)/origfico
winsor carage, gen(wcarage) p(.01)

save ./tmp/auto_credit_clean_trim.dta, replace

